<?php

namespace Nwb\MultiDownloaderClient;

class FileRequest
{
    /**
     * @var string
     */
    private $url;
    /**
     * @var string
     */
    private $fallbackUrl;
    /**
     * @var FileOptions
     */
    private $fileOptions;
    /**
     * @var Metadata
     */
    private $metadata;
    /**
     * @var ImageEditOptions
     */
    private $imageEditOptions;

    public function __construct(string $url, string $fallbackUrl = null)
    {
        $this->url = $url;
        $this->fallbackUrl = $fallbackUrl;

        $this->fileOptions = new FileOptions();
        $this->metadata = new Metadata();
        $this->imageEditOptions = new ImageEditOptions();
    }

    public function url(string $url)
    {
        $this->url = $url;

        return $this;
    }

    public function fallbackUrl(string $fallbackUrl)
    {
        $this->fallbackUrl = $fallbackUrl;

        return $this;
    }

    public function fileOptions(FileOptions $fileOptions)
    {
        $this->fileOptions = $fileOptions;

        return $this;
    }

    public function getFileOptions(): FileOptions
    {
        return $this->fileOptions;
    }

    public function metadata(Metadata $metadata)
    {
        $this->metadata = $metadata;

        return $this;
    }

    public function getMetadata(): Metadata
    {
        return $this->metadata;
    }

    public function imageEditOptions(ImageEditOptions $imageEditOptions)
    {
        $this->imageEditOptions = $imageEditOptions;

        return $this;
    }

    public function getImageEditOptions(): ImageEditOptions
    {
        return $this->imageEditOptions;
    }

    public function getUrl(): string
    {
        return $this->url;
    }

    public function getFallbackUrl(): string
    {
        return $this->fallbackUrl;
    }

    public function toArray(): array
    {
        return array_filter([
            'url' => $this->url,
            'fallbackUrl' => $this->fallbackUrl,
            'fileOptions' => $this->fileOptions->toArray(),
            'metadata' => $this->metadata->toArray(),
            'imageEditOptions' => $this->imageEditOptions->toArray()
        ]);
    }
}
